@@ -430,7 +430,7 @@ class DynamoDBModel(object):
         update an existing one (iff allow_overwrite == True -- otherwise,
         the operation fails with OverwriteError).
         """
-        table = ConnectionBorg().get_table(self.__table__)
+        table = ConnectionBorg().get_table(type(self).__table__)
         item_data = self.to_db_dict()
         item = Item(table, attrs=item_data)
 
@@ -466,5 +466,5 @@ class DynamoDBModel(object):
         else:
             range_key_value = None
 
-        table = ConnectionBorg().get_table(self.__table__)
+        table = ConnectionBorg().get_table(type(self).__table__)
         Item(table, hash_key_value, range_key_value).delete()
